==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/FunctionBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.FunctionBody;
import io.ciera.tool.sql.ooaofooa.body.FunctionBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNCSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_SYNCSetImpl;

import java.util.Arrays;
import java.util.List;


public class FunctionBodySetImpl extends InstanceSet<FunctionBodySet,FunctionBody> implements FunctionBodySet {

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( FunctionBody functionbody : this ) functionbody.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setSync_ID( UniqueId ref_Sync_ID ) throws XtumlException {
        for ( FunctionBody functionbody : this ) functionbody.setSync_ID( ref_Sync_ID );
    }


    // selections
    @Override
    public S_SYNCSet R695_specifies_processing_for_S_SYNC() throws XtumlException {
        S_SYNCSet s_syncset = new S_SYNCSetImpl();
        for ( FunctionBody functionbody : this ) s_syncset.add( functionbody.R695_specifies_processing_for_S_SYNC() );
        return s_syncset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( FunctionBody functionbody : this ) bodyset.add( functionbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public FunctionBody nullElement() {
        return FunctionBodyImpl.EMPTY_FUNCTIONBODY;
    }

    @Override
    public FunctionBodySet emptySet() {
      return new FunctionBodySetImpl();
    }

    @Override
    public FunctionBodySet value() {
        return this;
    }

    @Override
    public List<FunctionBody> elements() {
        return Arrays.asList(toArray(new FunctionBody[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/FunctionBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.FunctionBody;
import io.ciera.tool.sql.ooaofooa.body.FunctionBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNCSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_SYNCSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class FunctionBodySetImpl extends InstanceSet<FunctionBodySet,FunctionBody> implements FunctionBodySet {

    public FunctionBodySetImpl() {
    }

    public FunctionBodySetImpl(Comparator<? super FunctionBody> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( FunctionBody functionbody : this ) functionbody.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setSync_ID( UniqueId ref_Sync_ID ) throws XtumlException {
        for ( FunctionBody functionbody : this ) functionbody.setSync_ID( ref_Sync_ID );
    }


    // selections
    @Override
    public S_SYNCSet R695_specifies_processing_for_S_SYNC() throws XtumlException {
        S_SYNCSet s_syncset = new S_SYNCSetImpl();
        for ( FunctionBody functionbody : this ) s_syncset.add( functionbody.R695_specifies_processing_for_S_SYNC() );
        return s_syncset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( FunctionBody functionbody : this ) bodyset.add( functionbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public FunctionBody nullElement() {
        return FunctionBodyImpl.EMPTY_FUNCTIONBODY;
    }

    @Override
    public FunctionBodySet emptySet() {
      return new FunctionBodySetImpl();
    }

    @Override
    public FunctionBodySet emptySet(Comparator<? super FunctionBody> comp) {
      return new FunctionBodySetImpl(comp);
    }

    @Override
    public FunctionBodySet value() {
        return this;
    }

    @Override
    public List<FunctionBody> elements() {
        return Arrays.asList(toArray(new FunctionBody[0]));
    }

}
